pub type SyncStore<T> = Store<T, CopyValue<T, SyncStorage>>;Expand description
A type alias for a store backed by SyncStorage.
Aliased Type
pub struct SyncStore<T> { /* private fields */ }pub type SyncStore<T> = Store<T, CopyValue<T, SyncStorage>>;A type alias for a store backed by SyncStorage.
pub struct SyncStore<T> { /* private fields */ }